@@ -26,6 +26,7 @@ import threading
 import traceback
 from collections import namedtuple
 from datetime import datetime, timedelta
+from operator import attrgetter
 from pathlib import Path, PurePosixPath
 from string import Formatter
 from typing import Mapping
@@ -175,6 +176,23 @@ def help_formatter(argwidth=40, raw_description=False):
     return lambda prog: FluxHelpFormatter(prog, max_help_position=argwidth)
 
 
+def get_treedict(in_dict, key, default=None):
+    """
+    get_treedict(d, "a.b.c" [,default=None]) is like:
+    >>> try:
+    >>>     return d[a][b][c]
+    >>> except KeyError:
+    >>>     return default
+    """
+    if "." in key:
+        next_key, rest = key.split(".", 1)
+        try:
+            return get_treedict(in_dict[next_key], rest, default)
+        except KeyError:
+            return default
+    return in_dict.get(key, default)
+
+
 def set_treedict(in_dict, key, val):
     """
     set_treedict(d, "a.b.c", 42) is like d[a][b][c] = 42
@@ -554,10 +572,32 @@ class AltField:
 
 
 class OutputFormat:
-    """
-    Store a parsed version of the program's output format,
-    allowing the fields to iterated without modifiers, building
-    a new format suitable for headers display, etc...
+    """Extended output format container class for Flux utilities.
+
+    The OutputFormat class stores a parsed version of a program's output
+    format, allowing fields to be iterated without their corresponding
+    modifiers, automatic creation of a format string suitable for header
+    display, as well as some other features specific to Flux utility
+    output including:
+
+     - Support for format prefix "sentinels" ``?:``, ``+:`` and ``?+:``
+       which suppress fields that would be empty, expand fields automatically
+       to their maximum obsevered width, or both.
+     - Support for embedding a set of sort keys in a format via a
+       ``sort:KEY,...`` prefix.
+     - A ``print_items()`` method to handle the common code for sorting,
+       filtering and printing a set of items using the current format.
+
+    Attributes:
+        formatter (Formatter): a custom string formatter that will be used to
+            render output using its ``format()`` method. The default
+            formatter is :py:class:`flux.util.UtilFormatter`
+        headings (dict): A mapping of field name to header string. This also
+            provides detection of invalid fields, so all valid fields should
+            have an entry in headings. The headings dict can be set as an
+            argument to :py:func:`OutputFormat.__init__`, or a subclass of
+            the :py:class`flux.util.OutputFormat` class may set default
+            headings for a given tool.
     """
 
     formatter = UtilFormatter
@@ -580,19 +620,19 @@ class OutputFormat:
 
     def __init__(self, fmt, headings=None, prepend="0."):
         """
-        Parse the input format fmt with string.Formatter.
+        Parse the input format ``fmt`` with string.Formatter.
         Save off the fields and list of format tokens for later use,
         (converting None to "" in the process)
 
-        Throws an exception if any format fields do not match the allowed
-        list of headings.
+        Args:
+            headings (dict): Set a mapping of field name to header string.
+            prepend (str): Prepend each field with a string. (Default is
+                "0.", so ``{f1} {f2}`` becomes ``{0.f1} {0.f2}``.
         """
         if headings is not None:
             self.headings = headings
         if prepend is not None:
             self.prepend = prepend
-        self.fmt = fmt
-        self.fmt_orig = fmt
         #  Parse format into list of (string, field, spec, conv) tuples,
         #   replacing any None values with empty string "" (this makes
         #   substitution back into a format string in self.header() and
@@ -600,8 +640,31 @@ class OutputFormat:
         format_list = Formatter().parse(fmt)
         self.format_list = [[s or "" for s in t] for t in format_list]
 
+        #  If the first entry's text portion starts with `sort:`, then
+        #  what follows is a list of sort keys (used only in print_items())
+        #
+        #  self.sort_keys is a list of (key(str), reverse(bool)) tuples.
+        self.sort_keys = []
+        if self.format_list and self.format_list[0][0].startswith("sort:"):
+            #  Remove sort:keys, prefix from format_list, replace with
+            #   empty string:
+            sort_spec = self.format_list[0][0]
+            self.format_list[0][0] = ""
+
+            #  Store sort keys for later use
+            self.set_sort_keys(sort_spec[5:])
+
+            #  Strip sort_spec from beginning of fmt
+            fmt = fmt.lstrip(sort_spec)
+
+        #  Save format after removal of sort keys:
+        self.fmt = fmt
+        self.fmt_orig = fmt
+
         #  Store list of requested fields in self.fields
-        self._fields = [field for (_, field, _, _) in self.format_list]
+        #  (ignore any empty fields, which may be present due to text
+        #   at the end of a format string):
+        self._fields = [field for (_, field, _, _) in self.format_list if field]
 
         #  Throw an exception if any requested fields are invalid:
         for field in self._fields:
@@ -612,11 +675,102 @@ class OutputFormat:
 
         #  Prepend arbitrary string to format fields if requested
         if self.prepend:
-            self.fmt = self.get_format_prepended(self.prepend)
+            self.fmt = self.get_format_prepended(
+                self.prepend, include_sort_prefix=False
+            )
+
+    class FormatSpec:
+        """Split Python format spec into components"""
+
+        # Note: 'hyphen' and 'truncate' are Flux extensions
+        components = (
+            "fill",
+            "align",
+            "sign",
+            "pos_zero",
+            "alt",
+            "zero_pad",
+            "width_str",
+            "grouping",
+            "decimal",
+            "precision_str",
+            "type",
+            "hyphen",
+            "truncate",
+        )
+
+        def __init__(self, spec):
+
+            # If spec contains two colons ('::') then this is a special
+            # datetime conversion spec and the format spec is after the
+            # two colons:
+            if "::" in spec:
+                spec = spec[spec.find("::") + 2 :]
+
+            # Regex taken from https://stackoverflow.com/a/78351366
+            # 'hyphen' and 'truncate' are Flux extensions
+            spec_re = re.compile(
+                r"(?:(?P<fill>[\s\S])?(?P<align>[<>=^]))?"
+                r"(?P<sign>[- +])?"
+                r"(?P<pos_zero>z)?"
+                r"(?P<alt>#)?"
+                r"(?P<zero_pad>0)?"
+                r"(?P<width_str>\d+)?"
+                r"(?P<grouping>[_,])?"
+                r"(?:(?P<decimal>\.)(?P<precision_str>\d+))?"
+                r"(?P<type>[bcdeEfFgGnosxX%])?"
+                r"(?P<hyphen>h)?"
+                r"(?P<truncate>\+)?"
+            )
+            try:
+                self._spec_dict = spec_re.fullmatch(spec).groupdict()
+            except AttributeError:
+                self._spec_dict = {}
+
+            for item in self.components:
+                value = self._spec_dict.get(item)
+                setattr(self, item, "" if value is None else value)
+
+        @property
+        def width(self):
+            return int(self.width_str) if self.width_str else ""
+
+        @width.setter
+        def width(self, val):
+            self.width_str = str(val)
+
+            # Also adjust precision if necessary (only for string type)
+            if (
+                self.type in (None, "s")
+                and self.precision
+                and self.precision < self.width
+            ):
+                self.precision = self.width
+
+        @property
+        def precision(self):
+            return int(self.precision_str) if self.precision_str else 0
+
+        @precision.setter
+        def precision(self, val):
+            self.precision_str = str(val)
+
+        def __str__(self):
+            result = ""
+            for item in self.components:
+                value = getattr(self, item)
+                if value is not None:
+                    result += str(value)
+            return result
 
     @property
     def fields(self):
-        return self._fields
+        # Add any sort keys to returned fields for users like flux-jobs(1),
+        # which need to translate requested fields to job-list attributes:
+        fields = set(self._fields.copy())
+        if self.sort_keys:
+            fields.update([x for x, y in self.sort_keys])
+        return list(fields)
 
     # This should be a method, not a function since it is overridden by
     # inheriting classes
@@ -634,35 +788,43 @@ class OutputFormat:
 
     def header_format(self):
         """
-        Return the header row formatted by the user-provided format spec,
-        which will be made "safe" for use with string headings.
+        Return the current format sanitized for use in formatting a header
+        row. All format specs are adjusted to keep only the align and width,
+        and any numeric formatting types are dropped since the header row
+        is made up of only strings.
         """
         format_list = []
         for text, field, spec, _ in self.format_list:
-            #  Remove number formatting on any spec:
-            spec = re.sub(r"(0?\.)?(\d+)?[bcdoxXeEfFgGn%]$", r"\2", spec)
+            spec = self.FormatSpec(spec)
 
-            #  Only keep fill, align, and min width of the result.
+            #  Only keep align and min width of the result.
             #  This strips possible type-specific formatting spec that
             #   will not apply to a heading, but keeps width and alignment.
-            match = re.search(r"([<>=^])?(\d+)", spec)
-            if match is None:
-                spec = ""
-            else:
-                spec = match[0]
+            spec = f"{spec.align}{spec.width}"
+
             #  Remove any conversion, these do not make sense for headings
             format_list.append(self._fmt_tuple(text, field, spec, None))
         fmt = "".join(format_list)
         return fmt
 
     def header(self):
+        """Return a header row using the current format"""
         formatter = self.HeaderFormatter()
         return formatter.format(self.header_format(), **self.headings)
 
-    def get_format_prepended(self, prepend, except_fields=None):
+    def get_format_prepended(
+        self, prepend, except_fields=None, include_sort_prefix=True
+    ):
         """
         Return the format string, ensuring that the string in "prepend"
         is prepended to each format field
+
+        Args:
+            prepend (str): String to prepend to each field name, e.g. "0."
+            except_fields (list): List of fields to skip  when constructing
+                the format.
+            include_sort_prefix (bool): If format specifies a list of sort
+                keys, include them in a ``sort:`` prefix. Default: True
         """
         if except_fields is None:
             except_fields = []
@@ -677,20 +839,38 @@ class OutputFormat:
             if field and not field.startswith(prepend):
                 field = prepend + field
             lst.append(self._fmt_tuple(text, field, spec, conv))
-        return "".join(lst)
+        if include_sort_prefix:
+            prefix = self._sort_prefix()
+        else:
+            prefix = ""
+        return prefix + "".join(lst)
 
-    def get_format(self, orig=False):
+    def _sort_prefix(self):
+        if self.sort_keys:
+            keys = [f"-{x}" if rev else x for x, rev in self.sort_keys]
+            return "sort:" + ",".join(keys) + " "
+        return ""
+
+    def get_format(self, orig=False, include_sort_prefix=True):
         """
         Return the format string
+        Args:
+            orig (bool): Return the format as originally specified.
+            include_sort_prefix (bool): If the format includes a list of
+                sort keys, include a ``sort:`` prefix in the result.
         """
-        if orig:
-            return self.fmt_orig
-        return self.fmt
+        fmt = self.fmt_orig if orig else self.fmt
+        if include_sort_prefix:
+            return self._sort_prefix() + fmt
+        return fmt
 
     def copy(self, except_fields=None):
         """
         Return a copy of the current formatter, optionally with some
         fields removed
+
+        Args:
+            except_fields (list): List of fields to remove from result.
         """
         cls = self.__class__
         return cls(
@@ -700,71 +880,174 @@ class OutputFormat:
         )
 
     def format(self, obj):
-        """
-        format object with internal format
-        """
+        """Format object with internal format"""
         try:
-            retval = self.formatter().format(self.get_format(), obj)
+            retval = self.formatter().format(
+                self.get_format(include_sort_prefix=False), obj
+            )
         except KeyError as exc:
             typestr = type(obj)
             raise KeyError(f"Invalid format field {exc} for {typestr}")
         return retval
 
-    def filter_empty(self, items):
+    def filter(self, items):
         """
-        Check for format fields that are prefixed with `?:` (e.g. "?:{name}")
+        Check for format fields that are prefixed with `?:` (e.g. "?:{name}"),
         and filter them out of the current format string if they result in an
         empty value (as defined by the `empty` tuple defined below) for every
         entry in `items`.
+
+        Also, check for fields prefixed with `+:` (e.g. "+:{name}") and expand
+        those fields to the maximum observed width.
+
+        (`?+:` requests both actions: filter out field if it is empty for all
+        items, if not expand to maximum width)
         """
-        #  Build a list of all format strings that have the collapsible
-        #  sentinel '?:' to determine which are subject to the test for
-        #  emptiness.
+
+        #  Build a list of all format strings that have one of the width
+        #  adjustment sentinels to determine which are subject to the test for
+        #  emptiness/maxwidth.
+        #
+        sentinels = {"?:": "filter", "+:": "maxwidth", "?+:": "both"}
+
+        def sentinel_keys():
+            #  helper function to iterate supported sentinels by longest
+            #  first to avoid matching `+:` instead of `?+:`, etc.
+            #
+            return sorted(sentinels.keys(), key=lambda x: -len(x))
+
+        lst = []
+        index = 0
+
+        #  Loop over each format entry to find entries using any one
+        #  of the sentinels above:
         #
         #  Note: we remove the leading `text` and the format `spec` because
         #  these may make even empty formatted fields non-empty. E.g. a spec
         #  of `:>8` will always make the format result 8 characters wide.
         #
-        lst = []
-        index = 0
-        for text, field, _, conv in self.format_list:
-            if text.endswith("?:"):
+        for text, field, spec, conv in self.format_list:
+            # Determine if field has any supported sentinel above:
+            end = next((x for x in sentinel_keys() if text.endswith(x)), False)
+
+            if end:
+                #  This entry matches one of the filtering sentinels, parse
+                #  the spec to get current width (and allow possible
+                #  reconstruction later).
+                spec = self.FormatSpec(spec)
+
+                #  Save a format without any spec to allow determination of
+                #  maximum width after formatting all items:
                 fmt = self._fmt_tuple("", "0." + field, None, conv)
-                lst.append(dict(fmt=fmt, index=index))
+
+                #  Save the modified format, index, type, maximum width,
+                #  observed width, and broken-down spec in lst:
+                lst.append(
+                    dict(
+                        fmt=fmt,
+                        index=index,
+                        type=sentinels[end],
+                        maxwidth=spec.width or 0,
+                        width=0,
+                        spec=spec,
+                    )
+                )
             index = index + 1
 
-        # Return immediately if no format fields are collapsible
+        # Return immediately if no format fields need filtering:
         if not lst:
             return self.get_format(orig=True)
 
         formatter = self.formatter()
 
-        #  Iterate over all items, rebuilding lst each time to contain
-        #  only those fields that resulted in non-"empty" strings:
+        #  Get a list of outputs that would qualify as "empty"
         empty = empty_outputs()
-        for item in items:
-            lst = [x for x in lst if formatter.format(x["fmt"], item) in empty]
 
-            #  If lst is now empty, that means all fields already returned
-            #  nonzero strings, so we can break early
-            if not lst:
-                break
+        #  Loop over all items that will be printed and capture the max
+        #  width. This will later be used to either filter out the format
+        #  field entirely, or update the width to the maximum value:
+        for item in items:
+            for entry in lst:
+                result = formatter.format(entry["fmt"], item)
+                width = 0 if result in empty else len(result)
+                if width > entry["maxwidth"]:
+                    entry["maxwidth"] = width
+                if width > entry["width"]:
+                    entry["width"] = width
+
+        #  Create two new lists from lst:
+        #
+        #  remove: These entries have 0 width and were requested to be removed
+        #
+        #  new_lst: lst without those entries in `remove`. These entries
+        #      have nonzero width and/or are requesting max width be
+        #      substituted into the format spec.
+        #
+        remove = []
+        new_lst = []
+        for entry in lst:
+            if entry["width"] == 0 and entry["type"] in ("filter", "both"):
+                remove.append(entry["index"])
+            else:
+                new_lst.append(entry)
+        lst = new_lst
+
+        #  For any remaining entries in lst, update the format spec width
+        #  to the found maxwidth:
+        #
+        format_list = self.format_list.copy()
+        for entry in lst:
+            if entry["type"] in ("maxwidth", "both"):
+                entry["spec"].width = entry["maxwidth"]
+                format_list[entry["index"]][2] = str(entry["spec"])
 
         #  Remove any entries that were empty from self.format_list
-        #  (use index field of lst to remove by position in self.format_list)
-        format_list = [
-            x
-            for i, x in enumerate(self.format_list)
-            if i not in [x["index"] for x in lst]
-        ]
+        #  After this line saved indices in entry["index"] will no longer
+        #  be valid, so they should not be used after this point.
+        #
+        format_list = [x for i, x in enumerate(self.format_list) if i not in remove]
 
-        #  Remove "?:" from remaining entries so they disappear in output.
+        #  Remove sentinels from remaining entries so they disappear in output.
         for entry in format_list:
-            if entry[0].endswith("?:"):
-                entry[0] = entry[0][:-2]
+            for s in sentinel_keys():
+                entry[0] = entry[0].replace(s, "")
 
-        #  Return new format string created from pruned format_list
-        return "".join(self._fmt_tuple(*x) for x in format_list)
+        #  Return new format string:
+        return self._sort_prefix() + "".join(self._fmt_tuple(*x) for x in format_list)
+
+    def set_sort_keys(self, sort_keys):
+        """
+        Override current sort keys used in print_items() which may have
+        been set by a `sort:` prefix.
+
+        Args:
+            sort_keys (str): Comma separated list of sort keys. Prefix a
+                key with `-` to reverse sort on that key.
+        """
+        #  Reset self.sort_keys:
+        self.sort_keys = []
+        for key in sort_keys.split(","):
+            key = key.strip()
+            reverse = False
+            if key.startswith("-"):
+                reverse = True
+                key = key[1:]
+            if key not in self.headings:
+                raise ValueError("Invalid sort key: " + key)
+            self.sort_keys.append((key, reverse))
+
+    def sort_items(self, items):
+        """
+        Sort items using sort_keys attribute.
+
+        Args:
+            items (list): list of items to sort. Note that the list is
+                sorted in place and then returned.
+        """
+        # Apply any requested sort:
+        for key, reverse in reversed(self.sort_keys):
+            items.sort(key=attrgetter(key), reverse=reverse)
+        return items
 
     def print_items(self, items, no_header=False, pre=None, post=None):
         """
@@ -774,6 +1057,9 @@ class OutputFormat:
         fields, if requested. (The pre-processing step could be extended
         in the future.)
 
+        Next, sort items via any sort keys as set by set_sort_keys() or
+        via a ``sort:`` prefix in the supplied format.
+
         Then, generate a header unless no_header is True.
 
         Finally output a formatted line for each provided item.
@@ -784,12 +1070,15 @@ class OutputFormat:
             pre (callable): Function to call before printing each item
             post (callable): Function to call after printing each item
         """
-        #  Preprocess original format by processing with filter_empty():
-        newfmt = self.filter_empty(items)
+        #  Preprocess original format by processing with filter():
+        newfmt = self.filter(items)
         #  Get the current class for creating a new formatter instance:
         cls = self.__class__
         #  Create new instance of the current class from filtered format:
         formatter = cls(newfmt, headings=self.headings, prepend=self.prepend)
+
+        items = self.sort_items(items)
+
         if not no_header:
             print(formatter.header())
         for item in items:
