@@ -1,8 +1,8 @@
-# 1 "/__w/flux-python/flux-python/src/_core_clean.h"
-# 1 "<built-in>"
-# 1 "<command-line>"
+# 0 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 0 "<built-in>"
+# 0 "<command-line>"
 # 1 "/usr/include/stdc-predef.h" 1 3 4
-# 1 "<command-line>" 2
+# 0 "<command-line>" 2
 # 1 "/__w/flux-python/flux-python/src/_core_clean.h"
 # 48 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef void (*flux_free_f)(void *arg);
@@ -486,6 +486,8 @@ typedef struct flux_watcher flux_watcher_t;
 
 typedef void (*flux_watcher_f)(flux_reactor_t *r, flux_watcher_t *w,
                                int revents, void *arg);
+# 712 "/__w/flux-python/flux-python/src/_core_clean.h"
+void flux_watcher_set_priority (flux_watcher_t *w, int priority);
 
 void flux_watcher_start (flux_watcher_t *w);
 void flux_watcher_stop (flux_watcher_t *w);
@@ -575,11 +577,12 @@ void flux_stat_watcher_get_rstat (flux_watcher_t *w,
 
 
 struct flux_watcher_ops {
+    void (*set_priority) (flux_watcher_t *w, int priority);
     void (*start) (flux_watcher_t *w);
     void (*stop) (flux_watcher_t *w);
     void (*destroy) (flux_watcher_t *w);
 };
-# 805 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 815 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_watcher_t * flux_watcher_create (flux_reactor_t *r, size_t data_size,
                                       struct flux_watcher_ops *ops,
                                       flux_watcher_f fn, void *arg);
@@ -591,7 +594,7 @@ void * flux_watcher_get_data (flux_watcher_t *w);
 
 
 struct flux_watcher_ops * flux_watcher_get_ops (flux_watcher_t *w);
-# 844 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 854 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_msg_handler flux_msg_handler_t;
 
 typedef void (*flux_msg_handler_f)(flux_t *h, flux_msg_handler_t *mh,
@@ -638,7 +641,7 @@ void flux_msg_handler_delvec (flux_msg_handler_t *msg_handlers[]);
 
 
 int flux_dispatch_requeue (flux_t *h);
-# 921 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 931 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef flux_t *(connector_init_f)(const char *uri,
                                    int flags,
                                    flux_error_t *errp);
@@ -671,7 +674,7 @@ flux_t *flux_handle_create (void *impl,
                             const struct flux_handle_ops *ops,
                             int flags);
 void flux_handle_destroy (flux_t *hp);
-# 984 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 994 "/__w/flux-python/flux-python/src/_core_clean.h"
 struct flux_msglist *flux_msglist_create (void);
 void flux_msglist_destroy (struct flux_msglist *l);
 
@@ -685,10 +688,10 @@ const flux_msg_t *flux_msglist_next (struct flux_msglist *l);
 const flux_msg_t *flux_msglist_last (struct flux_msglist *l);
 
 int flux_msglist_count (struct flux_msglist *l);
-# 1005 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1015 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_msglist_pollevents (struct flux_msglist *l);
 int flux_msglist_pollfd (struct flux_msglist *l);
-# 1041 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1051 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_request_decode (const flux_msg_t *msg, const char **topic,
                          const char **s);
 
@@ -719,11 +722,11 @@ flux_msg_t *flux_request_encode (const char *topic, const char *s);
 
 flux_msg_t *flux_request_encode_raw (const char *topic,
                                      const void *data, int len);
-# 1107 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1117 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_response_decode (const flux_msg_t *msg,
                           const char **topic,
                           const char **s);
-# 1119 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1129 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_response_decode_raw (const flux_msg_t *msg,
                               const char **topic,
                               const void **data,
@@ -788,11 +791,11 @@ int flux_respond_error (flux_t *h,
                         const flux_msg_t *request,
                         int errnum,
                         const char *errstr);
-# 1211 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1221 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_msg_t *flux_control_encode (int type, int status);
 
 int flux_control_decode (const flux_msg_t *msg, int *type, int *status);
-# 1272 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1282 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef void (*flux_log_f)(const char *buf, int len, void *arg);
 
 
@@ -844,7 +847,7 @@ void flux_llog (void *arg,
                 int level,
                 const char *fmt,
                 va_list ap);
-# 1342 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1352 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_future flux_future_t;
 
 typedef void (*flux_continuation_f)(flux_future_t *f, void *arg);
@@ -910,7 +913,7 @@ const char * flux_future_first_child (flux_future_t *cf);
 const char * flux_future_next_child (flux_future_t *cf);
 
 flux_future_t *flux_future_get_child (flux_future_t *cf, const char *name);
-# 1420 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1430 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_future_and_then (flux_future_t *f,
                                      flux_continuation_f cb, void *arg);
 
@@ -938,7 +941,7 @@ void flux_future_continue_error (flux_future_t *prev, int errnum,
 int flux_future_fulfill_next (flux_future_t *prev,
                               void *result,
                               flux_free_f free_fn);
-# 1462 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1472 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_RPC_NORESPONSE = 1,
     FLUX_RPC_STREAMING = 2,
@@ -989,7 +992,7 @@ uint32_t flux_rpc_get_matchtag (flux_future_t *f);
 
 
 uint32_t flux_rpc_get_nodeid (flux_future_t *f);
-# 1540 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1550 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum event_flags {
     FLUX_EVENT_PRIVATE = 1,
 };
@@ -1070,7 +1073,7 @@ flux_future_t *flux_event_publish_raw (flux_t *h,
 
 
 int flux_event_publish_get_seq (flux_future_t *f, int *seq);
-# 1651 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1661 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_MODSTATE_INIT = 0,
     FLUX_MODSTATE_RUNNING = 1,
@@ -1096,7 +1099,7 @@ bool flux_module_debug_test (flux_t *h, int flag, bool clear);
 
 
 int flux_module_set_running (flux_t *h);
-# 1724 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1734 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_attr_get (flux_t *h, const char *name);
 
 
@@ -1135,7 +1138,7 @@ const char *flux_get_hostbyrank (flux_t *h, uint32_t rank);
 
 
 int flux_get_rankbyhost (flux_t *h, const char *host);
-# 1776 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1786 "/__w/flux-python/flux-python/src/_core_clean.h"
 char *flux_hostmap_lookup (flux_t *h,
                            const char *targets,
                            flux_error_t *errp);
@@ -1146,7 +1149,7 @@ char *flux_hostmap_lookup (flux_t *h,
 
 
 int flux_get_instance_starttime (flux_t *h, double *starttime);
-# 1814 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1824 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum flux_conf_flags {
     FLUX_CONF_INSTALLED=0,
     FLUX_CONF_INTREE=1,
@@ -1199,13 +1202,13 @@ int flux_conf_vunpack (const flux_conf_t *conf,
 int flux_conf_unpack (const flux_conf_t *conf,
                       flux_error_t *error,
                       const char *fmt, ...);
-# 1898 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1908 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_barrier (flux_t *h, const char *name, int nprocs);
-# 1941 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1951 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_service_register (flux_t *h, const char *name);
-# 1953 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1963 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_service_unregister (flux_t *h, const char *name);
-# 2005 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2015 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_core_version_string (void);
 
 
@@ -1214,7 +1217,7 @@ const char *flux_core_version_string (void);
 
 
 int flux_core_version (int *major, int *minor, int *patch);
-# 2043 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2053 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_PLUGIN_RTLD_LAZY = 1,
     FLUX_PLUGIN_RTLD_NOW = 2,
@@ -1292,7 +1295,7 @@ flux_plugin_f flux_plugin_match_handler (flux_plugin_t *p, const char *topic);
 int flux_plugin_register (flux_plugin_t *p,
                           const char *name,
                           const struct flux_plugin_handler t[]);
-# 2130 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2140 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_aux_set (flux_plugin_t *p,
                          const char *key,
                          void *val,
@@ -1354,14 +1357,14 @@ int flux_plugin_arg_unpack (flux_plugin_arg_t *args, int flags,
                             const char *fmt, ...);
 int flux_plugin_arg_vunpack (flux_plugin_arg_t *args, int flags,
                              const char *fmt, va_list ap);
-# 2199 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2209 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_call (flux_plugin_t *p, const char *name,
                       flux_plugin_arg_t *args);
-# 2209 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2219 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_load_dso (flux_plugin_t *p, const char *path);
-# 2242 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2252 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_sync_create (flux_t *h, double minimum);
-# 2274 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2284 "/__w/flux-python/flux-python/src/_core_clean.h"
 bool flux_disconnect_match (const flux_msg_t *msg1, const flux_msg_t *msg2);
 
 
@@ -1381,7 +1384,7 @@ bool flux_cancel_match (const flux_msg_t *msg1, const flux_msg_t *msg2);
 int flux_msglist_cancel (flux_t *h,
                          struct flux_msglist *l,
                          const flux_msg_t *msg);
-# 2343 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2353 "/__w/flux-python/flux-python/src/_core_clean.h"
 void flux_stats_count (flux_t *h, const char *name, ssize_t count);
 
 
@@ -1417,10 +1420,10 @@ void flux_stats_set_prefix (flux_t *h, const char *fmt, ...);
 
 
 bool flux_stats_enabled (flux_t *h, const char *metric);
-# 2426 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2436 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_kvsdir flux_kvsdir_t;
 typedef struct flux_kvsitr flux_kvsitr_t;
-# 2441 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2451 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_kvsdir_t *flux_kvsdir_create (flux_t *handle,
                                    const char *rootref,
                                    const char *key,
@@ -1468,7 +1471,7 @@ const char *flux_kvsdir_rootref (const flux_kvsdir_t *dir);
 
 
 char *flux_kvsdir_key_at (const flux_kvsdir_t *dir, const char *key);
-# 2516 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2526 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_lookup (flux_t *h,
                                 const char *ns,
                                 int flags,
@@ -1495,14 +1498,14 @@ const char *flux_kvs_lookup_get_key (flux_future_t *f);
 
 
 int flux_kvs_lookup_cancel (flux_future_t *f);
-# 2570 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2580 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_getroot (flux_t *h, const char *ns, int flags);
-# 2579 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2589 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_kvs_getroot_get_treeobj (flux_future_t *f, const char **treeobj);
 int flux_kvs_getroot_get_blobref (flux_future_t *f, const char **blobref);
 int flux_kvs_getroot_get_sequence (flux_future_t *f, int *seq);
 int flux_kvs_getroot_get_owner (flux_future_t *f, uint32_t *owner);
-# 2611 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2621 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_kvs_txn flux_kvs_txn_t;
 
 flux_kvs_txn_t *flux_kvs_txn_create (void);
@@ -1553,7 +1556,7 @@ int flux_kvs_txn_symlink (flux_kvs_txn_t *txn,
 int flux_kvs_txn_clear (flux_kvs_txn_t *txn);
 
 bool flux_kvs_txn_is_empty (flux_kvs_txn_t *txn);
-# 2710 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2720 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum kvs_commit_flags {
     FLUX_KVS_NO_MERGE = 1,
     FLUX_KVS_TXN_COMPACT = 2,
@@ -1576,21 +1579,21 @@ flux_future_t *flux_kvs_fence (flux_t *h,
 int flux_kvs_commit_get_treeobj (flux_future_t *f, const char **treeobj);
 int flux_kvs_commit_get_rootref (flux_future_t *f, const char **rootref);
 int flux_kvs_commit_get_sequence (flux_future_t *f, int *rootseq);
-# 2771 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2781 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_copy (flux_t *h,
                               const char *srcns,
                               const char *srckey,
                               const char *dstns,
                               const char *dstkey,
                               int commit_flags);
-# 2788 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2798 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_move (flux_t *h,
                               const char *srcns,
                               const char *srckey,
                               const char *dstns,
                               const char *dstkey,
                               int commit_flags);
-# 2811 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2821 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum kvs_op {
     FLUX_KVS_READDIR = 1,
     FLUX_KVS_READLINK = 2,
@@ -1602,7 +1605,7 @@ enum kvs_op {
     FLUX_KVS_WATCH_UNIQ = 128,
     FLUX_KVS_WATCH_APPEND = 256
 };
-# 2832 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2842 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_namespace_create (flux_t *h,
                                           const char *ns,
                                           uint32_t owner,
@@ -1626,7 +1629,7 @@ int flux_kvs_wait_version (flux_t *h, const char *ns, int version);
 
 
 int flux_kvs_dropcache (flux_t *h);
-# 2883 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2893 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum job_submit_flags {
     FLUX_JOB_PRE_SIGNED = 1,
     FLUX_JOB_DEBUG = 2,
@@ -1704,10 +1707,10 @@ typedef uint64_t flux_jobid_t;
 
 
 int flux_job_id_parse (const char *s, flux_jobid_t *id);
-# 2969 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2979 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_id_encode (flux_jobid_t id, const char *type,
                         char *buf, size_t bufsz);
-# 2980 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2990 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_job_statetostr (flux_job_state_t state, const char *fmt);
 
 
@@ -1821,11 +1824,11 @@ flux_future_t *flux_job_result (flux_t *h, flux_jobid_t id, int flags);
 
 int flux_job_result_get (flux_future_t *f,
                          const char **json_str);
-# 3111 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3121 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_result_get_unpack (flux_future_t *f, const char *fmt, ...);
-# 3125 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3135 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_timeleft (flux_t *h, flux_error_t *errp, double *timeleft);
-# 3141 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3151 "/__w/flux-python/flux-python/src/_core_clean.h"
 char *flux_unwrap_string (const char *in,
                           bool verify,
                           uint32_t *userid,
@@ -1837,7 +1840,7 @@ char *flux_unwrap_string (const char *in,
 
 
 int flux_job_waitstatus_to_exitcode (int waitstatus, flux_error_t *errp);
-# 3176 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3186 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_jobspec1 flux_jobspec1_t;
 typedef flux_error_t flux_jobspec1_error_t;
 
@@ -1935,7 +1938,7 @@ char *flux_jobspec1_encode (flux_jobspec1_t *jobspec, size_t flags);
 
 flux_jobspec1_t *flux_jobspec1_decode (const char *s,
                                        flux_jobspec1_error_t *error);
-# 3287 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3297 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_jobspec1_t *flux_jobspec1_from_command (int argc,
                                              char **argv,
                                              char **env,
@@ -1947,7 +1950,7 @@ flux_jobspec1_t *flux_jobspec1_from_command (int argc,
 
 
 void flux_jobspec1_destroy (flux_jobspec1_t *jobspec);
-# 3343 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3353 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_command flux_cmd_t;
 
 
@@ -2031,14 +2034,14 @@ const char *flux_cmd_getenv (const flux_cmd_t *cmd, const char *name);
 
 int flux_cmd_setcwd (flux_cmd_t *cmd, const char *cwd);
 const char *flux_cmd_getcwd (const flux_cmd_t *cmd);
-# 3439 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3449 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_cmd_add_channel (flux_cmd_t *cmd, const char *name);
-# 3476 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3486 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_cmd_setopt (flux_cmd_t *cmd, const char *var, const char *val);
 const char *flux_cmd_getopt (flux_cmd_t *cmd, const char *var);
-# 3497 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3507 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_subprocess flux_subprocess_t;
-# 3509 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3519 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef enum {
     FLUX_SUBPROCESS_INIT,
     FLUX_SUBPROCESS_RUNNING,
@@ -2058,10 +2061,11 @@ enum {
 
     FLUX_SUBPROCESS_FLAGS_STDIO_FALLTHROUGH = 1,
 
-    FLUX_SUBPROCESS_FLAGS_SETPGRP = 2,
+    FLUX_SUBPROCESS_FLAGS_NO_SETPGRP = 2,
+
 
     FLUX_SUBPROCESS_FLAGS_FORK_EXEC = 4,
-# 3541 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3552 "/__w/flux-python/flux-python/src/_core_clean.h"
     FLUX_SUBPROCESS_FLAGS_LOCAL_UNBUF = 8,
 };
 
@@ -2074,12 +2078,11 @@ typedef void (*flux_subprocess_output_f) (flux_subprocess_t *p,
                                           const char *stream);
 typedef void (*flux_subprocess_state_f) (flux_subprocess_t *p,
                                          flux_subprocess_state_t state);
+typedef void (*flux_subprocess_credit_f) (flux_subprocess_t *p,
+                                          const char *stream,
+                                          int bytes);
 typedef void (*flux_subprocess_hook_f) (flux_subprocess_t *p, void *arg);
-
-
-
-
-
+# 3580 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct {
     flux_subprocess_f on_completion;
 
@@ -2089,6 +2092,7 @@ typedef struct {
     flux_subprocess_output_f on_channel_out;
     flux_subprocess_output_f on_stdout;
     flux_subprocess_output_f on_stderr;
+    flux_subprocess_credit_f on_credit;
 } flux_subprocess_ops_t;
 
 
@@ -2113,7 +2117,7 @@ typedef void (*subprocess_log_f)(void *arg,
                                  int level,
                                  const char *fmt,
                                  va_list args);
-# 3614 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3636 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_subprocess_t *flux_local_exec (flux_reactor_t *r,
                                     int flags,
                                     const flux_cmd_t *cmd,
@@ -2148,7 +2152,7 @@ flux_subprocess_t *flux_rexec_ex (flux_t *h,
 
 void flux_subprocess_stream_start (flux_subprocess_t *p, const char *stream);
 void flux_subprocess_stream_stop (flux_subprocess_t *p, const char *stream);
-# 3658 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3680 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_write (flux_subprocess_t *p,
                            const char *stream,
                            const char *buf,
@@ -2160,11 +2164,11 @@ int flux_subprocess_write (flux_subprocess_t *p,
 
 
 int flux_subprocess_close (flux_subprocess_t *p, const char *stream);
-# 3686 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3708 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_read (flux_subprocess_t *p,
                           const char *stream,
                           const char **bufp);
-# 3706 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3734 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_read_line (flux_subprocess_t *p,
                                const char *stream,
                                const char **bufp);
@@ -2175,10 +2179,10 @@ int flux_subprocess_read_line (flux_subprocess_t *p,
 int flux_subprocess_read_trimmed_line (flux_subprocess_t *p,
                                        const char *stream,
                                        const char **bufp);
-# 3725 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3753 "/__w/flux-python/flux-python/src/_core_clean.h"
 bool flux_subprocess_read_stream_closed (flux_subprocess_t *p,
                                          const char *stream);
-# 3743 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3771 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_getline (flux_subprocess_t *p,
                              const char *stream,
                              const char **bufp);
@@ -2210,6 +2214,11 @@ flux_subprocess_state_t flux_subprocess_state (flux_subprocess_t *p);
 
 const char *flux_subprocess_state_string (flux_subprocess_state_t state);
 
+
+
+
+bool flux_subprocess_active (flux_subprocess_t *p);
+
 int flux_subprocess_rank (flux_subprocess_t *p);
 
 
@@ -2267,7 +2276,7 @@ void *flux_subprocess_aux_get (flux_subprocess_t *p, const char *name);
 
 void flux_subprocess_channel_incref (flux_subprocess_t *p, const char *name);
 void flux_subprocess_channel_decref (flux_subprocess_t *p, const char *name);
-# 3846 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3879 "/__w/flux-python/flux-python/src/_core_clean.h"
 extern "Python" void message_handler_wrapper(flux_t *, flux_msg_handler_t *, const flux_msg_t *, void *);
 
 
